Index: dtc-lexer.l
===================================================================
--- dtc-lexer.l	(.../LinuxBIOSv3/util/dtc/dtc-lexer.l)	(revision 2)
+++ dtc-lexer.l	(.../coreboot-v3/util/dtc/dtc-lexer.l)	(working copy)
@@ -23,6 +23,7 @@
 %x CELLDATA
 %x BYTESTRING
 %x MEMRESERVE
+%x PASSTHROUGH
 
 PROPCHAR	[a-zA-Z0-9,._+*#?-]
 UNITCHAR	[0-9a-f,]
@@ -35,16 +36,33 @@
 
 #include "dtc-parser.tab.h"
 
-/*#define LEXDEBUG	1*/
-
 #ifdef LEXDEBUG
 #define DPRINT(fmt, ...)	fprintf(stderr, fmt, ##__VA_ARGS__)
 #else
 #define DPRINT(fmt, ...)	do { } while (0)
 #endif
 
+char *code = 0;
 
+YY_BUFFER_STATE bstack = NULL;
+int line;
 
+void
+switchin(FILE *f){
+	YY_BUFFER_STATE b;
+	bstack = YY_CURRENT_BUFFER;
+	b = yy_create_buffer(f, 8192);
+	line = yylineno;
+	yylineno = 1;
+	yy_switch_to_buffer(b);
+	
+}
+
+void
+switchback(void){
+		yy_switch_to_buffer(bstack);
+		yylineno = line;
+}


This is for switching input via /config/("filename");

 %}
 
 %%
@@ -58,6 +76,22 @@
 			return DT_STRING;
 		}
 
+^%%\n	{
+			DPRINT("Begin passthrough\n");
+			/* let's be stupid. 1 MB is way more than enough ... */
+			code = malloc(1048576);
+			*code = 0;
+			BEGIN(PASSTHROUGH);
+		}
+
+<PASSTHROUGH>.*	{
+					DPRINT("Matching in passthrough %s\n", yytext);
+					/* you tell me why echo does not work */
+					/*ECHO;*/
+					strcat(code, yytext);
+					strcat(code, "\n");
+				}
+
AFAIK the passthrough stuff is dead and no longer used. This would be removed. 

 "/memreserve/"	{
 			yylloc.first_line = yylineno;
 			DPRINT("Keyword: /memreserve/\n");
@@ -67,7 +101,7 @@
 
 <MEMRESERVE>[0-9a-fA-F]+ {
 			yylloc.first_line = yylineno;
-			if (yyleng > 2*sizeof(yylval.addr)) {
+			if ((unsigned long)yyleng > 2*sizeof(yylval.addr)) {
 				fprintf(stderr, "Address value %s too large\n",
 					yytext);
 			}
@@ -84,9 +118,15 @@
 			return ';';
 		}
 
+"/config/"	{
+			yylloc.first_line = yylineno;
+			DPRINT("Keyword: /config/\n");
+			return DT_CONFIG;
+		}
+

implements DT_CONFIG 
 <CELLDATA>[0-9a-fA-F]+	{
 			yylloc.first_line = yylineno;
-			if (yyleng > 2*sizeof(yylval.cval)) {
+			if ((unsigned long)yyleng > 2*sizeof(yylval.cval)) {
 				fprintf(stderr,
 					"Cell value %s too long\n", yytext);
 			}
